- x
output from the bootstrap function.
- add
logical, with default FALSE, specifying whether to create
a new plot or add to the current one.
- out
character vector specifying the output to be plotted, either the
mean equated scores ("mean"), standard errors ("se"), bias
("bias"), or RMSE ("rmse").
- xpoints, ypoints
optional vectors of the same length containing raw
scores on forms X and Y, assuming a single group or equivalent groups
design.
- addident
logical, with default TRUE, for plotting the identity
function. The result depends on out.
- identy
vector of y coordinates for plotting the identity line.
Defaults to the identity function when out = "eqs", otherwise, a
horizontal line with intercept 0.
- identcol
color used for plotting the identity line.
- rescale
intercept and slope, with default 0 and 1, used to rescale
all lines before plotting.
- xlab, ylab, col, pch, lty
graphical parameters passed to par, with
the lengths of col and lty recycled as necessary.
- subset
vector for subsetting the output when multiple equating
functions are included in x.
- morepars
list of additional graphical parameters, excluding
xlab, ylab, col, pch, lty.
- addlegend
logical, with default TRUE, indicating whether or
not a legend should be added.
- legendtext
character vector of text to be passed to the legend
argument of the legend function, defaulting to a combination of the
equating types and methods specified in each equating object.
- legendplace
placement of the legend.
- ...
further arguments passed to or from other methods, excluding
graphical parameters.